#

class Success(object):
  def __init__(self, payload, warnings=None, dirruns=None):
    """
    Some operations, e.g., scheduling might be essentially successful,
    but still produce some warning and might have failed to schedule
    a run on the respective directory at a given list of times. So,
    basically, we have the writer monad; this class models it.

    @type warnings: list of string, or None
    @type dirruns: list of int, or None
    """
    self.payload = payload
    if warnings is None:
      warnings = []
    self.warnings = warnings
    if dirruns is None:
      dirruns = []
    self.dirruns = dirruns

  def __str__(self):
    return str(self.payload)

  def __repr__(self):
    s = "Success(" + repr(self.payload)
    if len(self.dirruns) > 0:
      s += ", dirruns=" + repr(self.dirruns)
    if len(self.warnings) > 0:
      s += ", warnings=" + repr(self.warnings)
    return s + ")"

  def __eq__(self, other):
    if not isinstance(other, Success):
      return NotImplemented

    return self.payload == other.payload and self.warnings == other.warnings \
      and self.dirruns == other.dirruns

  def then(self, v):
    """
    The (>>) operator.

    @type v: Success
    """
    return Success(v.payload, warnings=self.warnings + v.warnings,
                   dirruns = self.dirruns + v.dirruns)

  def after(self, v):
    return v.then(self)

  @staticmethod
  def forM_(xs, f):
    """
    The forM_ function.
    """
    temp = Success(None)

    for x in xs:
      temp = temp.then(f(x))

    return temp.then(Success(None))


class ScheduleError(Exception):
  pass

class ConfigError(Exception):
  pass

class ScheduleRetry(Exception):
  pass
