#

import configparser
import os.path

from scheduledmail.common import ConfigError

SCHEDULEDIR=".mailschedule"

AT="at"
QUEUERUNNER="mail-schedule-do.pl"

needed_configs = ["HELO", "FROM",
                  "SIMPLE_FROM", "SIMPLE_TO", "SIMPLE_LOG",
                  "INTERNAL_CONTROL", "SUBMIT",
                  "scheduledir", "at", "queuerunner"]

def parse_config(filenames):
    config = configparser.ConfigParser()

    try:
        for filename in filenames:
            config.read(filename)
    except Exception as e:
        raise ConfigError("Failed to read config file '%s': %s"
                          % (filename, e))

    if not 'SCHEDULER' in config:
        raise ConfigError("'SCHEDULER' section missing")
    config = config['SCHEDULER']

    if not all( elem in config for elem in needed_configs):
        raise ConfigError("Missing config items: needed '%s', found '%s'"
                          % (needed_configs, list(config.keys())))

    try:
        if not os.path.isdir(config['scheduledir']):
            raise ConfigError("Missing schedule dir: %s"
                              % (config['scheduledir'],))
    except Exception as e:
        raise ConfigError(
            "Failed to check for existance of schedule dir '%s': %s"
            % (config['scheduledir'], e))

    try:
        with open(os.path.join(config['scheduledir'], 'secret'), 'r') as secret:
            config['secret'] = secret.read()
    except Exception as e:
        raise ConfigError(
            "Failed to get secret: %s" % (e,))

    return config
