#

import hashlib
import hmac
import os
import time

# Shorten all hashes to that many hex digist, to keep the length
# managable; we're not providing a high-security service anyway,
# just enough to avoid accidental matches and to keep spammers out.
SECURITY_PARAMETER=12

def timeprefix(epoch):
  return ("%x" % epoch)[:-4]

def timeprefix_valid(prefix, now=None):
  if now is None:
    now = int(time.time())
  # we drop the last 4 hex digits, i.e., 16 bits
  now = now // (2**16)
  try:
    prefix_time = int(prefix, 16)
  except ValueError:
    return False
  return now <= prefix_time

def token(time, uniq, secret):
  msg = "%s:%s" % (timeprefix(time), uniq)
  sig = hmac.new(secret.encode(), msg.encode(), digestmod='sha1').hexdigest()
  return "%s:%s" % (msg, sig[:SECURITY_PARAMETER])

def generate_token(secret, identifier, count, validuntil):
  randombytes = os.urandom(SECURITY_PARAMETER // 2)
  uniqdatabytes = ("%s:%s:" % (identifier, count)).encode() + randombytes
  m = hashlib.sha1()
  m.update(uniqdatabytes)
  uniq = m.hexdigest()[:SECURITY_PARAMETER]
  return token(time=validuntil, uniq=uniq, secret=secret)

def token_valid(token, secret, now=None):
  if now is None:
    now = int(time.time())
  parts = token.split(':')
  if len(parts) != 3:
    return False
  if not timeprefix_valid(parts[0], now=now):
    return False
  msg = "%s:%s" % (parts[0], parts[1])
  sig = hmac.new(secret.encode(), msg.encode(),
                 digestmod='sha1').hexdigest()[:SECURITY_PARAMETER]
  return parts[2][:SECURITY_PARAMETER] == sig
