#
import scheduledmail.mailtoken

from scheduledmail.common import Success, ScheduleError

STOP_COMMANDS = ["quit", "stop", "thank", "thanks", "thankyou", "--"] \
                + ["%s%s" % (word, interpunction)
                    for word in ["hi", "hello", "hallo"] for interpunction in ["", ",", "!"]]

MAX_BAD_COMMANDS = 3

def parse_command_block(text, commands = [], alternatives = None,
                        look_for_token=False, secret=""):
  """
  Take a block of text and list of allowed commands (besides the stop
  command), and parse the initial command block.

  Return as Success object of a list of commands, each as a list, in
  order (as some commands are cummulative, others latest wins, we cannot
  further accumulate).
  """
  if alternatives is None:
    alternatives = {}
  result = []
  warnings = []
  bad_count = 0
  token = []

  stop_check_for_commands = False

  lines = text.splitlines()
  for line in lines:
    if len(line) == 0:
      continue
    # Use standard full quote generated my a typical MTA as comment signs.
    if line.startswith('>') or line.startswith('#') or line.startswith("On "):
      continue
    words = line.split()
    if len(words) < 1:
      continue

    words[0] = words[0].lower()

    if look_for_token:
      if scheduledmail.mailtoken.token_valid(words[-1], secret):
        token.append(words[-1])

    if words[0] in STOP_COMMANDS:
      break

    if words[0] in alternatives:
      words[0] = alternatives[words[0]]

    if words[0] in commands:
      if not stop_check_for_commands:
        result.append(words)
    else:
      if not stop_check_for_commands:
        warnings.append("Ignoring line: %s" % (line,))
      bad_count += 1

    if bad_count > MAX_BAD_COMMANDS:
      warnings.append("Too many malformed commands found, bailing out")
      stop_check_for_commands = True

      if not look_for_token:
        break
      elif bad_count > MAX_BAD_COMMANDS * 2:
        break

  if look_for_token:
    if len(token) == 0:
      return None
    else:
      return Success((token, result), warnings=warnings)
  else:
    return Success(result, warnings=warnings)
