#
from time import strftime, gmtime

from scheduledmail.lgtm import format_lgtm_status
from scheduledmail.templates import SUBMIT_SUCCESS
from scheduledmail.unit import Unit

def cc_rcpt(ccs):
  return "".join(["\nRCPT TO: %s" % cc for cc in ccs])

def cc_header(cc):
  return ", ".join(cc)

def answerUnit(rcpt, cc, inreply, warnings, config, mid, identifier, time,
               references, names=[], extrafiles={}):
  warn = ""
  warnstatus = ""
  if len(warnings) > 0:
    warnstatus = " with WARNINGS"
    warn = "\n\nHowever, there were some warnings.\n - " \
           + "\n - ".join(warnings)
  parts = ""
  if len(names) > 1:
    parts = "\n\nThe following units where scheduled\n - " \
            + "\n - ".join(["%s/%s" % (identifier,name) for name in names])
  cleartexttime = strftime("%Y-%m-%d %H:%M UTC", gmtime(time))
  dayofweek = strftime("%A", gmtime(time))
  extradesc=""
  if "SUSPENDED" in extrafiles:
    extradesc += "\n\nThe mail is suspended.\n"
    extradesc += "\n".join([" | " + line
                            for line in extrafiles["SUSPENDED"].splitlines()])
  if "WANT_LGTM" in extrafiles:
    extradesc += ("\n\nThere is a review requirement: %s"
                  % (format_lgtm_status(extrafiles["WANT_LGTM"]),))
  if "DESCRIPTION" in extrafiles:
    extradesc += "\n\nThe mail was described as follows.\n"
    extradesc += "\n".join([" | " + line
                            for line in extrafiles["DESCRIPTION"].splitlines()])
  bsmtp = SUBMIT_SUCCESS.format(
    rcpt=rcpt, inreply=inreply, warn=warn, mid=mid,
    references=references,
    warnstatus = warnstatus,
    identifier=identifier, time=time,
    helo = config["HELO"], mailfrom = config["FROM"],
    cc_hdr=cc_header(cc), additional_rcpt=cc_rcpt(cc),
    cleartexttime=cleartexttime,
    dayofweek = dayofweek,
    extradesc = extradesc,
    parts=parts)
  return Unit(bsmtp, name="answer")
