#

from email.message import EmailMessage

from scheduledmail.util import quote_dots

SUBMISSION_ANSWER_MID = "<submission-{identifier}@{helo}>"
BATCH_ANSWER_MID = "<batch-{identifier}@{helo}>"
SCHEDULED_MAIL_SENT_MID = "<done-{identifier}@{helo}>"
INTERNAL_ANSWER_MID = "<internal-answer-{identifier}@{helo}>"
ANNOUNCE_MID = "<announce-{identifier}@{helo}>"
SCHEDULED_MAIL_PART_SENT_MID = "<done-{identifier}/{name}@{helo}>"
FINAL_CMD_MAIL_MID = "<after-{identifier}/{name}@{helo}>"
TOKEN_MAIL_MID = "<control-{identifier}/{name}@{helo}>"
PAYLOAD_MID = "<{identifier}/{name}@{helo}>"

PURGE_HEADERS = ['Date', 'X-mutt-fcc', 'X-Mutt-References', 'BCC']


default_header_fmt = {
  'From' : '{mailfrom}',
  'To' : '{rcpt}',
  'CC' : '{cc_hdr}',
  'Message-ID' : '{mid}',
  'In-Reply-To' : '{inreply}',
  'References' : '{references}',
  'X-schedule-service': '{helo}',
}

default_kwargs = {
  'additional_rcpt': '',
  'cc_hdr' : '',
}

default_prolog ="""HELO {helo}
MAIL FROM: {mailfrom}
RCPT TO: {rcpt}{additional_rcpt}
DATA
"""

class Template:
  def __init__(self, template, *, subject_fmt,
               header_fmt=default_header_fmt, prolog=default_prolog):
    self.template = template
    self.subject_fmt = subject_fmt
    self.header_fmt = header_fmt
    self.prolog = prolog

  def format(self, **kwargs):
    kwargs = dict(default_kwargs, **kwargs)
    pre_data = self.prolog.format(**kwargs)
    mail = EmailMessage()
    for hdr, fmt in self.header_fmt.items():
      hdr_value = fmt.format(**kwargs)
      if hdr_value:
        mail[hdr] = hdr_value
    mail['Subject'] = self.subject_fmt.format(**kwargs)
    mail.set_content(self.template.format(**kwargs), cte='quoted-printable')
    return (pre_data
            + quote_dots(mail.as_string(maxheaderlen=76))
            + '.\nQUIT\n')

# NOTE: all mail templates start with a stop word.
#       Keep it that way to avoid accidents!

BATCH_FAIL= Template("""
Hi

your attempt to batch a mail for later delivery
failed for the following reasons

{messages}

I'm sorry,
the mail scheduling service
""", subject_fmt="mail scheduling batch FAILED")

BATCH_SUCCESS = Template("""Hi

your mail was successfulliy batched.{warn}

Thanks,
the mail scheduling service
""", subject_fmt = 'scheduling batch SUCCEEDED{warnstatus}')

SUBMIT_FAIL = Template("""Hi

your attempt to schedule a mail for later delivery
failed for the following reasons

{messages}

I'm sorry,
the mail scheduling service
""", subject_fmt = "mail scheduling submission FAILED")


SUBMIT_SUCCESS= Template("""Hi

your mail was successfulliy scheduled.{warn}

The internal identifier is

  {identifier}

and it is scheduled to be sent at {time} seconds
since the epoch, also known as {cleartexttime}
and that date is a {dayofweek}.{parts}{extradesc}

Thanks,
the mail scheduling service
""", subject_fmt="scheduling submission SUCCEEDED as {identifier}{warnstatus}")

SCHEDULED_MAIL_SENT=Template("""Hi

Your scheduled mail {identifier} was sent out.{actdesc}

Thanks,
the mail scheduling service
""", subject_fmt = "{identifier} SENT")

FINAL_CMD_MAIL=Template("""{cmdblockquoted}
thanks

Hi

Since {identifier} was sent out, let's update some mail tasks.
""", prolog ="""HELO {helo}
MAIL FROM: {user}
RCPT TO: {internalcontrol}
RCPT TO: {user}
DATA
""", header_fmt = dict(default_header_fmt, **{
  'From': '{user}',
  'To' : '{internalcontrol}',
 }), subject_fmt = "Re: {identifier} SENT")

INTERNAL_ANSWER = Template("""Hi

your mail was successfulliy processed.{warn}{ans}

Thanks,
the mail scheduling service
""", subject_fmt="Succeded for {successfull}/{processed} {status}")

ANNOUNCE=Template("""Hi

this is your reminder (requested by {origcmd}) for

  {identifier}

which you originally scheduled for {epoch} seconds since the epoch.
{msg}{suspmsg}{actdesc}

Thanks,
the mail scheduling service
""", subject_fmt="Announcement for {identifier}")


TOKEN_DESC = {
  'veto' : 'You may stop {unit} from being sent by telling me\n'
            + '  veto {unit} {token}\n\n',
  'unveto': 'You may remove a veto for {unit} by telling me\n'
            + '  unveto {unit} {token}\n\n',
  'lgtm': 'You may approve of {unit} by telling me\n'
            + '  lgtm {unit} {token}\n\n',
}

PART_DESC_ANNOUNCE = "Here is a summary of {unit}.\n"

TOKEN_MAIL=Template("""Hi

you have been granted control over scheduled mails.

{descs}{actdesc}

To tell me, {mailfrom}, something,
write the command, on a line by its own, at
the beginning of the mail and terminate the block of commands by the
'stop' command (you can also use one of its aliases like 'thanks'
or 'quit'). I will read your mail line by line from the beginning
till I find a stop command; I will consider lines starting with
'#', '>', or 'On ' as comments and silently ignore them.

Thanks,
the mail scheduling service
""", subject_fmt="Control token for mail scheduled mails")

BATCH_PROLOG="desc BATCH of {count} mails submitted via the batch scheduler.\n"
