#!/usr/bin/perl

use strict;


@ARGV != 1 and do {
    print "Usage $0 <scheduledir>\n";
    exit(-1);
};

my $scheduledir = $ARGV[0];

opendir (my $sdh, $scheduledir) or die "Failed to open dir $scheduledir ($!)\n";
my @schedules = readdir($sdh);
closedir ($sdh) or die "Failed to close dir $scheduledir ($!)\n";

chdir $scheduledir or die "Failed to change to $scheduledir ($!)\n";

my @allunits = ();

foreach my $schedule (@schedules) {
    $schedule =~ /^[0-9]/ or next;
    opendir (my $sdh, $schedule) or die "Failed to open dir $schedule ($!)\n";
    my @units = readdir($sdh);
    closedir($sdh) or die "Failed to close dir $schedule ($!)\n";

    chdir $schedule or die "Failed to change to $schedule ($!)\n";
    foreach my $unit (@units) {
        -d $unit or next;
        $unit =~ /^[0-9]/ or next;
        my ($schedtime, $unit_name) = split /\./, $unit, 2;


		my $desc = "";
        -f "$unit/DESCRIPTION" and do {
            open(DESC, "<", "$unit/DESCRIPTION")
                or die "failed to open $unit/DESCRIPTION ($!)\n";
            $desc = do {local $/; <DESC>};
            close(DESC) or die "failed to close $unit/DESCRIPTION ($!)\n";
        };
		my $susp = "";
		-f "$unit/SUSPENDED" and $susp = " SUSPENDED";
		push @allunits, [$schedtime, "$schedule/$unit_name", $desc, $susp];
    }
    chdir $scheduledir or die "Failed to change to $scheduledir ($!)\n";
};

for my $unitdesc (sort{@{$a}[0] <=> @{$b}[0]} @allunits) {
	my ($time, $name, $desc, $susp) = @{$unitdesc};
	printf "%-25s %11d %s%s\n",  $name, $time, scalar localtime $time, $susp;
	if (length($desc) > 0) {
		$desc =~ s/^/    /gm;
		print "$desc";
	}
};
