#!/usr/bin/env bats

load '../../bats-support/load'
load '../../bats-file/load'

function setup {
    TEST_TEMP_DIR="$(temp_make)"
    mkdir "${TEST_TEMP_DIR}/schedule"
    cp test/data/test_config.ini "${TEST_TEMP_DIR}"
    cat << EOF > "${TEST_TEMP_DIR}/overwrite_config.ini"
[SCHEDULER]
scheduledir = ${TEST_TEMP_DIR}/schedule
EOF
    ed "${TEST_TEMP_DIR}/test_config.ini" <<EOI
/^scheduledir
d
a
scheduledir = ${TEST_TEMP_DIR}/schedule
.
w
q
EOI
    echo -n 'test_secret' > ${TEST_TEMP_DIR}/schedule/secret

    cat > ${TEST_TEMP_DIR}/generate_token.py <<'EOF'
import time
import scheduledmail.mailtoken
from scheduledmail.util import simpleQuote

token = scheduledmail.mailtoken.token(
          time=int(time.time()) + 24 * 60 * 60,
          uniq="testToken",
          secret="test_secret")
quoted_token = simpleQuote(token)

print("%s\n%s" % (token, quoted_token))
EOF
}

function teardown {
    temp_del "$TEST_TEMP_DIR"
}

@test "external suspend does not crash and inserts SUSPENDED" {
    UNIT=${TEST_TEMP_DIR}/schedule/1559328580.29555/1559410200.MAIN
    mkdir -p $UNIT
    touch $UNIT/payload.bsmtp

    token_quotedtoken=$(env PYTHONPATH=`pwd` python3 ${TEST_TEMP_DIR}/generate_token.py)
    token=$(echo "${token_quotedtoken}" | head -n 1)
    quotedtoken=$(echo "${token_quotedtoken}" | tail -n 1)

    echo 'veto' > ${UNIT}/token-${quotedtoken}
    cp test/data/internal_suspend.mail ${TEST_TEMP_DIR}/external_suspend.mail
    ed ${TEST_TEMP_DIR}/external_suspend.mail <<EOF
\$
?^suspend
s/suspend/veto
s/\$/ ${token}
w
q
EOF

    run sh -c "cat ${TEST_TEMP_DIR}/external_suspend.mail | env PYTHONPATH=`pwd` python3 scheduledmail/external_service.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]

    cat ${TEST_TEMP_DIR}/schedule/*/0*/payload.bsmtp

    assert_file_exist $UNIT/SUSPENDED
    assert_file_exist ${TEST_TEMP_DIR}/schedule/muted/${quotedtoken}
}
