
#!/usr/bin/env bats

load '../../bats-support/load'
load '../../bats-file/load'

function setup {
    TEST_TEMP_DIR="$(temp_make)"
    mkdir "${TEST_TEMP_DIR}/schedule"
    cp test/data/test_config.ini "${TEST_TEMP_DIR}"
    cat << EOF > "${TEST_TEMP_DIR}/overwrite_config.ini"
[SCHEDULER]
scheduledir = ${TEST_TEMP_DIR}/schedule
EOF
    ed "${TEST_TEMP_DIR}/test_config.ini" <<EOI
/^scheduledir
d
a
scheduledir = ${TEST_TEMP_DIR}/schedule
.
w
q
EOI
    echo 'test_secret' > ${TEST_TEMP_DIR}/schedule/secret
}

function teardown {
    temp_del "$TEST_TEMP_DIR"
}

@test "internal suspend does not crash and inserts SUSPENDED" {
    UNIT=${TEST_TEMP_DIR}/schedule/1559328580.29555/1559410200.MAIN
    mkdir -p $UNIT
    touch $UNIT/payload.bsmtp

    run sh -c "cat test/data/internal_suspend.mail | env PYTHONPATH=`pwd` python3 scheduledmail/internal_service.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
    assert_file_exist $UNIT/SUSPENDED
}


@test "internal reschedule does not crash and reschedules" {
    ACT=${TEST_TEMP_DIR}/schedule/1559328580.29555
    UNIT=$ACT/1559410200.MAIN
    mkdir -p $UNIT
    touch $UNIT/payload.bsmtp

    run sh -c "cat test/data/internal_service.mail | env PYTHONPATH=`pwd` python3 scheduledmail/internal_service.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
    assert_file_exist $ACT/1590949200.MAIN/payload.bsmtp
    assert_file_not_exist $UNIT
}


@test "config overwrite works" {
    ed "${TEST_TEMP_DIR}/test_config.ini" <<EOI
/^scheduledir
d
a
scheduledir = ${TEST_TEMP_DIR}/does_not_exist
.
w
q
EOI
    ACT=${TEST_TEMP_DIR}/schedule/1559328580.29555
    UNIT=$ACT/1559410200.MAIN
    mkdir -p $UNIT
    touch $UNIT/payload.bsmtp

    run sh -c "cat test/data/internal_service.mail | env PYTHONPATH=`pwd` python3 scheduledmail/internal_service.py  $TEST_TEMP_DIR/test_config.ini $TEST_TEMP_DIR/overwrite_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
    assert_file_exist $ACT/1590949200.MAIN/payload.bsmtp
    assert_file_not_exist $UNIT
}
