#!/usr/bin/env bats

load '../../bats-support/load'
load '../../bats-file/load'

function setup {
    TEST_TEMP_DIR="$(temp_make)"
    mkdir "${TEST_TEMP_DIR}/schedule"
    cp test/data/test_config.ini "${TEST_TEMP_DIR}"
    ed "${TEST_TEMP_DIR}/test_config.ini" <<EOI
/^scheduledir
d
a
scheduledir = ${TEST_TEMP_DIR}/schedule
.
w
q
EOI
    echo 'test_secret' > ${TEST_TEMP_DIR}/schedule/secret
}

function teardown {
    temp_del "$TEST_TEMP_DIR"
}

@test "attachment submission does not crash (A)" {
    run sh -c "cat test/data/submit-attach.mail | env PYTHONPATH=`pwd` python3 scheduledmail/submit.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}

@test "attachment submission does not crash (B)" {
    run sh -c "cat test/data/submit-attach-B.mail | env PYTHONPATH=`pwd` python3 scheduledmail/submit.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}

@test "attachment submission does not crash (C)" {
    run sh -c "cat test/data/submit-attach-C.mail | env PYTHONPATH=`pwd` python3 scheduledmail/submit.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}

@test "bstmp submission does not crash" {
    run sh -c "cat test/data/submission.mail | env PYTHONPATH=`pwd` python3 scheduledmail/submit.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}

@test "batching does not crash (A)" {
    run sh -c "cat test/data/submit-attach.mail | env PYTHONPATH=`pwd` python3 scheduledmail/batch_service.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}

@test "batching does not crash (B)" {
    run sh -c "cat test/data/submit-attach-B.mail | env PYTHONPATH=`pwd` python3 scheduledmail/batch_service.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}

@test "simple submission does not crash (A)" {
    run sh -c "cat test/data/simple-submit.mail | env PYTHONPATH=`pwd` RECEIPIENT=you-reminder-05102130@example.local EXT4=05102130 python3 scheduledmail/simple_submit.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}

@test "simple submission does not crash (B)" {
    # Any mail can be used for simple submission, so just reuse some other example
    run sh -c "cat test/data/submission.mail | env PYTHONPATH=`pwd` RECEIPIENT=you-reminder-05102130-other%40example.com@example.local EXT4=05102130-other%40example.com python3 scheduledmail/simple_submit.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}




@test "missing payload submission does not crash" {
    run sh -c "cat test/data/missingpayload.mail | env PYTHONPATH=`pwd` python3 scheduledmail/submit.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}

@test "missing date submission does not crash" {
    run sh -c "cat test/data/badsubmission.mail | env PYTHONPATH=`pwd` python3 scheduledmail/submit.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
}

@test "Only one now-at is scheduled" {
    cat > "${TEST_TEMP_DIR}/at.sh" <<EOF
#!/bin/sh
  echo called \$@ >> ${TEST_TEMP_DIR}/calls
EOF
    chmod 700 "${TEST_TEMP_DIR}/at.sh"
    touch ${TEST_TEMP_DIR}/calls
    ed "${TEST_TEMP_DIR}/test_config.ini" <<EOI
1
/^at
d
a
at = ${TEST_TEMP_DIR}/at.sh
.
w
q
EOI
    run sh -c "cat test/data/submit-attach.mail | env PYTHONPATH=`pwd` python3 scheduledmail/batch_service.py  $TEST_TEMP_DIR/test_config.ini"
    echo "$output"
    [ "$status" -eq 0 ]
    cat ${TEST_TEMP_DIR}/calls
    [ `cat ${TEST_TEMP_DIR}/calls | wc -l` -eq 1 ]
}
